<?php
    /**
     * Author: Peter Hlavac (jungidee.at)
     * 
     * Purpose: Query UID @ finanz online and display address info
     * 
     * First get a webservice user @ finanz online to set FA_BENID, FA_PIN, FA_TID and FA_UID_TN
     * Read more here:
     * https://www.bmf.gv.at/egovernment/fon/fuer-softwarehersteller/BMF_UID_Abfrage_Webservice_V5.pdf?4le6sz
     * 
     */

    include 'SessionWSIService.php';
    include 'uidAbfrageService.php';

    $benid = FA_BENID;
    $pin   = FA_PIN;
    $tid   = FA_TID;
    $uid   = FA_UID_TN;  
    
  
    $vatid = "ATU66255429"; // use any VAT ID here

    if (isset ($vatid)) {

        $sessionWSIService = new SessionWSIService('SessionWSIService.wsdl');

        $login = new Login();

        $login->benid = $benid;
        $login->pin = $pin;
        $login->tid = $tid;

        $logout = new Logout();

        $logout->benid = $benid;    
        $logout->tid = $tid;

        $errMsg = null;

        try {        
            //$r = new LoginResponse();
            $r = $sessionWSIService->Login($login);        

            $uidAbfrageService = new uidAbfrageService('uidAbfrageService.wsdl');

            $uidAbfrageRequest = new uidAbfrageRequest();
            $uidAbfrageRequest->benid = $benid;
            $uidAbfrageRequest->tid = $tid;
            $uidAbfrageRequest->sessionid = $r->Result;
            $uidAbfrageRequest->stufe = 2;
            $uidAbfrageRequest->uid = $vatid;        
            $uidAbfrageRequest->uid_tn = $uid;

            $uidResponse = $uidAbfrageService->uidAbfrage($uidAbfrageRequest);

            $logout->id = $r->Result;

            //echo $r->Result;
            //print_r($uidResponse);
            //die;
            
            $country = substr($vatid, 0,2);
            $uid     = substr($vatid, 2);
            $address = 
                    $uidResponse->adrz1." ".$uidResponse->adrz2." ".
                    $uidResponse->adrz3." ".$uidResponse->adrz4." ".
                    $uidResponse->adrz5." ".$uidResponse->adrz6;
            $name = $uidResponse->name;
                    
            $sessionWSIService->Logout($logout);

            echo json_encode($uidResponse);
        //} catch (SoapFault $s) {
        //    print($s);
        } catch (Exception $e) {        
            $trace = $e->getTrace();
            $errMsg = $e->getMessage();
            echo json_encode($e);

            //echo $trace["faultstring"];
        }
        
        
    } else {
        $err = array('errno' => 1, 'errmsg' => 'No VATID given');
        echo json_encode($err);
    }
    
?>

           


